package main

import (
	"git.binarythought.com/cdramey/sdb"
	"git.binarythought.com/cdramey/sutron"
	"fmt"
	"bytes"
	"io/ioutil"
	"os"
)

func main() {
	if len(os.Args) < 2 {
		fmt.Fprintf(os.Stderr,
			"required argument missing\n")
		os.Exit(1)
	}

	raw, err := ioutil.ReadFile(os.Args[1])
	if err != nil {
		fmt.Fprintf(os.Stderr,
			"error reading \"%s\": %s\n",
			os.Args[1], err.Error())
	}

	sdbdata, err := sdb.ParseSDB(raw)
	if err != nil {
		fmt.Fprintf(os.Stderr,
			"%s\n", err.Error())
		os.Exit(1)
	}

	for _, i := range sdbdata.Elements {
		switch v := i.(type) {
			case sdb.MOPayload:
				// Seek forward to the First "B" - Sadly necessary
				// in certain scenarios
				l := bytes.Index(v.Payload, []byte("B"))
				if l != -1 {
					sutrondata, err := sutron.ParseSutronB(v.Payload[l:])
					if err != nil {
						fmt.Fprintf(os.Stderr,
							"%s\n", err.Error())
						os.Exit(1)
					}

					fmt.Printf("Sutron Block: %s\n", string(sutrondata.Block))
					fmt.Printf("Sutron Group: %s\n", string(sutrondata.Group))
					fmt.Printf("Sutron Delta: %s\n", string(sutrondata.Delta))
					fmt.Printf("Sutron Voltage: %s\n", string(sutrondata.Voltage))
				}
		}
	}
}
